# Package: generallibrary
Random useful code made by me, categorized into modules to be imported seperately.

## Installation
```
pip install generallibrary
```

## Usage example
```python
from generallibrary.values import clamp
print(clamp(-3.2, -1, 1))
# >>> -1
```